Improve this Doc View Source

A function that returns its first argument. This function is useful when writing code in the functional style.

    function transformer(transformationFn, value) {
      return (transformationFn || angular.identity)(value);
    };

    // E.g.
    function getResult(fn, input) {
      return (fn || angular.identity)(input);
    };

    getResult(function(n) { return n * 2; }, 21);   // returns 42
    getResult(null, 21);                            // returns 21
    getResult(undefined, 21);                       // returns 21

## Usage

`angular.identity(value);`

### Arguments

Param | Type | Details
--- | --- | ---
value | * | to be returned.

### Returns

* | the value passed in.